/***************************************************************************//**
 *   @file   AD7298.h
 *   @brief  Header file of AD7298 Driver.
 *   @author DBogdan (dragos.bogdan@analog.com)
********************************************************************************
 * Copyright 2012(c) Analog Devices, Inc.
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  - Neither the name of Analog Devices, Inc. nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *  - The use of this software may or may not infringe the patent rights
 *    of one or more patent holders.  This license does not release you
 *    from the requirement that you obtain separate licenses from these
 *    patent holders to use this software.
 *  - Use of the software either in source or binary form, must be run
 *    on or directly connected to an Analog Devices Inc. component.
 *
 * THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
********************************************************************************
 *   SVN Revision: 751
*******************************************************************************/
#ifndef __AD7298_H__
#define __AD7298_H__

/******************************************************************************/
/********************************* AD7298 *************************************/
/******************************************************************************/

/* AD7298 Additional Signals*/
#define AD7298_PD_RST_PIN_OUT           GPIO1_PIN_OUT
#define AD7298_PD_RST_SET_HIGH          GPIO1_PIN_HIGH
#define AD7298_PD_RST_SET_LOW           GPIO1_PIN_LOW
#define AD7298_PD_RST_STATE             GPIO1_PIN_STATE

#define AD7298_TSENSE_BSY_PIN_IN        GPIO2_PIN_IN
#define AD7298_TSENSE_BSY_STATE         GPIO2_STATE

/* AD7298 SPI Slave Address */
#define AD7298_SLAVE_ID    1

/* AD7298 Register Map */
#define AD7298_WRITE    (1 << 15)           // Write to control register.
#define AD7298_REPEAT   (1 << 14)           // Enable repeated conversion.
#define AD7298_CH(x)    (1 << (13 - (x)))   // Channel select.
#define AD7298_TSENSE   (1 << 5)            // Enable temperature conversion.
#define AD7298_EXTREF   (1 << 2)            // Enable external reference.
#define AD7298_TAVG     (1 << 1)            // Enable temperature sensor averaging.
#define AD7298_PPD      (1 << 0)            // Enable partial power-down mode.

/* Power Options */
#define AD7298_PWR_POWER_UP                 0
#define AD7298_PWR_PARTIAL_POWER_DOWN       1
#define AD7298_PWR_FULL_POWER_DOWN          2

/******************************************************************************/
/************************ Functions Declarations ******************************/
/******************************************************************************/

/*! Initializes the SPI communication peripheral. */
unsigned char AD7298_Init(void);

/*! Powers up or powers down the device. */
void AD7298_SetPower(unsigned char powerOption);

/*! Sets the Control Register. */
void AD7298_SetControlRegister(unsigned short value);

/*! Configures the conversion settings. */
void AD7298_ConfigConversion(unsigned char repeat,
                             unsigned short channels,
                             unsigned char extRef,
                             unsigned char tSense,
                             unsigned char tSenseAvg);

/*! Returns the conversion value and its corresponding channel index. */
void AD7298_GetConversionResult(unsigned short *convData, unsigned char *ch);

/*! Calculates the temperature in degrees Celsius. */
float AD7298_CalcTemp(unsigned short value, float vRef);

/*! Calculates the measured voltage. Vref is considered to be 2.5V. */
float AD7298_CalcVoltage(unsigned short value, float vRef);

#endif // __AD7298_H__
